==> box64_0.2.2+dfsg.orig.tar.xz: box64-0.2.2/src/wrapped/wrappedlibxcbxfixes_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_xfixes_barrier_end, 
//GO(xcb_xfixes_barrier_next, 
//GO(xcb_xfixes_change_cursor, 
//GO(xcb_xfixes_change_cursor_by_name, 
//GO(xcb_xfixes_change_cursor_by_name_checked, 
//GO(xcb_xfixes_change_cursor_by_name_name, 
//GO(xcb_xfixes_change_cursor_by_name_name_end, 
//GO(xcb_xfixes_change_cursor_by_name_name_length, 
//GO(xcb_xfixes_change_cursor_by_name_sizeof, 
//GO(xcb_xfixes_change_cursor_checked, 
//GO(xcb_xfixes_change_save_set, 
//GO(xcb_xfixes_change_save_set_checked, 
//GO(xcb_xfixes_copy_region, 
//GO(xcb_xfixes_copy_region_checked, 
//GO(xcb_xfixes_create_pointer_barrier, 
//GO(xcb_xfixes_create_pointer_barrier_checked, 
//GO(xcb_xfixes_create_pointer_barrier_devices, 
//GO(xcb_xfixes_create_pointer_barrier_devices_end, 
//GO(xcb_xfixes_create_pointer_barrier_devices_length, 
//GO(xcb_xfixes_create_pointer_barrier_sizeof, 
GO(xcb_xfixes_create_region, pFpuup)
//GO(xcb_xfixes_create_region_checked, 
//GO(xcb_xfixes_create_region_from_bitmap, 
//GO(xcb_xfixes_create_region_from_bitmap_checked, 
//GO(xcb_xfixes_create_region_from_gc, 
//GO(xcb_xfixes_create_region_from_gc_checked, 
//GO(xcb_xfixes_create_region_from_picture, 
//GO(xcb_xfixes_create_region_from_picture_checked, 
//GO(xcb_xfixes_create_region_from_window, 
//GO(xcb_xfixes_create_region_from_window_checked, 
//GO(xcb_xfixes_create_region_rectangles, 
//GO(xcb_xfixes_create_region_rectangles_iterator, 
//GO(xcb_xfixes_create_region_rectangles_length, 
//GO(xcb_xfixes_create_region_sizeof, 
//GO(xcb_xfixes_delete_pointer_barrier, 
//GO(xcb_xfixes_delete_pointer_barrier_checked, 
GO(xcb_xfixes_destroy_region, pFpu)
//GO(xcb_xfixes_destroy_region_checked, 
//GO(xcb_xfixes_expand_region, 
//GO(xcb_xfixes_expand_region_checked, 
//GO(xcb_xfixes_fetch_region, 
//GO(xcb_xfixes_fetch_region_rectangles, 
//GO(xcb_xfixes_fetch_region_rectangles_iterator, 
//GO(xcb_xfixes_fetch_region_rectangles_length, 
//GO(xcb_xfixes_fetch_region_reply, 
//GO(xcb_xfixes_fetch_region_sizeof, 
//GO(xcb_xfixes_fetch_region_unchecked, 
//GO(xcb_xfixes_get_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_and_name, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image_end, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image_length, 
//GO(xcb_xfixes_get_cursor_image_and_name_name, 
//GO(xcb_xfixes_get_cursor_image_and_name_name_end, 
//GO(xcb_xfixes_get_cursor_image_and_name_name_length, 
//GO(xcb_xfixes_get_cursor_image_and_name_reply, 
//GO(xcb_xfixes_get_cursor_image_and_name_sizeof, 
//GO(xcb_xfixes_get_cursor_image_and_name_unchecked, 
//GO(xcb_xfixes_get_cursor_image_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_cursor_image_end, 
//GO(xcb_xfixes_get_cursor_image_cursor_image_length, 
//GO(xcb_xfixes_get_cursor_image_reply, 
//GO(xcb_xfixes_get_cursor_image_sizeof, 
//GO(xcb_xfixes_get_cursor_image_unchecked, 
//GO(xcb_xfixes_get_cursor_name, 
//GO(xcb_xfixes_get_cursor_name_name, 
//GO(xcb_xfixes_get_cursor_name_name_end, 
//GO(xcb_xfixes_get_cursor_name_name_length, 
//GO(xcb_xfixes_get_cursor_name_reply, 
//GO(xcb_xfixes_get_cursor_name_sizeof, 
//GO(xcb_xfixes_get_cursor_name_unchecked, 
//GO(xcb_xfixes_hide_cursor, 
//GO(xcb_xfixes_hide_cursor_checked, 
DATA(xcb_xfixes_id, 8)
//GO(xcb_xfixes_intersect_region, 
//GO(xcb_xfixes_intersect_region_checked, 
//GO(xcb_xfixes_invert_region, 
//GO(xcb_xfixes_invert_region_checked, 
GO(xcb_xfixes_query_version, pFpuu)
GO(xcb_xfixes_query_version_reply, pFpup)
GO(xcb_xfixes_query_version_unchecked, pFpuu)
//GO(xcb_xfixes_region_end, 
//GO(xcb_xfixes_region_extents, 
//GO(xcb_xfixes_region_extents_checked, 
//GO(xcb_xfixes_region_next, 
//GO(xcb_xfixes_select_cursor_input, 
//GO(xcb_xfixes_select_cursor_input_checked, 
GO(xcb_xfixes_select_selection_input, pFppppu)
GO(xcb_xfixes_select_selection_input_checked, pFppppu)
//GO(xcb_xfixes_set_cursor_name, 
//GO(xcb_xfixes_set_cursor_name_checked, 
//GO(xcb_xfixes_set_cursor_name_name, 
//GO(xcb_xfixes_set_cursor_name_name_end, 
//GO(xcb_xfixes_set_cursor_name_name_length, 
//GO(xcb_xfixes_set_cursor_name_sizeof, 
//GO(xcb_xfixes_set_gc_clip_region, 
//GO(xcb_xfixes_set_gc_clip_region_checked, 
//GO(xcb_xfixes_set_picture_clip_region, 
//GO(xcb_xfixes_set_picture_clip_region_checked, 
//GO(xcb_xfixes_set_region, 
//GO(xcb_xfixes_set_region_checked, 
//GO(xcb_xfixes_set_region_rectangles, 
//GO(xcb_xfixes_set_region_rectangles_iterator, 
//GO(xcb_xfixes_set_region_rectangles_length, 
//GO(xcb_xfixes_set_region_sizeof, 
GO(xcb_xfixes_set_window_shape_region, pFpuuwwu)
GO(xcb_xfixes_set_window_shape_region_checked, pFpuuwwu)
//GO(xcb_xfixes_show_cursor, 
//GO(xcb_xfixes_show_cursor_checked, 
//GO(xcb_xfixes_subtract_region, 
//GO(xcb_xfixes_subtract_region_checked, 
//GO(xcb_xfixes_translate_region, 
//GO(xcb_xfixes_translate_region_checked, 
//GO(xcb_xfixes_union_region, 
//GO(xcb_xfixes_union_region_checked,

==> box64_0.2.6+dfsg.orig.tar.xz: box64-0.2.6/src/wrapped/wrappedlibxcbxfixes_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_xfixes_barrier_end, 
//GO(xcb_xfixes_barrier_next, 
//GO(xcb_xfixes_change_cursor, 
//GO(xcb_xfixes_change_cursor_by_name, 
//GO(xcb_xfixes_change_cursor_by_name_checked, 
//GO(xcb_xfixes_change_cursor_by_name_name, 
//GO(xcb_xfixes_change_cursor_by_name_name_end, 
//GO(xcb_xfixes_change_cursor_by_name_name_length, 
//GO(xcb_xfixes_change_cursor_by_name_sizeof, 
//GO(xcb_xfixes_change_cursor_checked, 
//GO(xcb_xfixes_change_save_set, 
//GO(xcb_xfixes_change_save_set_checked, 
//GO(xcb_xfixes_copy_region, 
//GO(xcb_xfixes_copy_region_checked, 
//GO(xcb_xfixes_create_pointer_barrier, 
//GO(xcb_xfixes_create_pointer_barrier_checked, 
//GO(xcb_xfixes_create_pointer_barrier_devices, 
//GO(xcb_xfixes_create_pointer_barrier_devices_end, 
//GO(xcb_xfixes_create_pointer_barrier_devices_length, 
//GO(xcb_xfixes_create_pointer_barrier_sizeof, 
GO(xcb_xfixes_create_region, pFpuup)
//GO(xcb_xfixes_create_region_checked, 
//GO(xcb_xfixes_create_region_from_bitmap, 
//GO(xcb_xfixes_create_region_from_bitmap_checked, 
//GO(xcb_xfixes_create_region_from_gc, 
//GO(xcb_xfixes_create_region_from_gc_checked, 
//GO(xcb_xfixes_create_region_from_picture, 
//GO(xcb_xfixes_create_region_from_picture_checked, 
//GO(xcb_xfixes_create_region_from_window, 
//GO(xcb_xfixes_create_region_from_window_checked, 
//GO(xcb_xfixes_create_region_rectangles, 
//GO(xcb_xfixes_create_region_rectangles_iterator, 
//GO(xcb_xfixes_create_region_rectangles_length, 
//GO(xcb_xfixes_create_region_sizeof, 
//GO(xcb_xfixes_delete_pointer_barrier, 
//GO(xcb_xfixes_delete_pointer_barrier_checked, 
GO(xcb_xfixes_destroy_region, pFpu)
//GO(xcb_xfixes_destroy_region_checked, 
//GO(xcb_xfixes_expand_region, 
//GO(xcb_xfixes_expand_region_checked, 
//GO(xcb_xfixes_fetch_region, 
//GO(xcb_xfixes_fetch_region_rectangles, 
//GO(xcb_xfixes_fetch_region_rectangles_iterator, 
//GO(xcb_xfixes_fetch_region_rectangles_length, 
//GO(xcb_xfixes_fetch_region_reply, 
//GO(xcb_xfixes_fetch_region_sizeof, 
//GO(xcb_xfixes_fetch_region_unchecked, 
//GO(xcb_xfixes_get_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_and_name, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image_end, 
//GO(xcb_xfixes_get_cursor_image_and_name_cursor_image_length, 
//GO(xcb_xfixes_get_cursor_image_and_name_name, 
//GO(xcb_xfixes_get_cursor_image_and_name_name_end, 
//GO(xcb_xfixes_get_cursor_image_and_name_name_length, 
//GO(xcb_xfixes_get_cursor_image_and_name_reply, 
//GO(xcb_xfixes_get_cursor_image_and_name_sizeof, 
//GO(xcb_xfixes_get_cursor_image_and_name_unchecked, 
//GO(xcb_xfixes_get_cursor_image_cursor_image, 
//GO(xcb_xfixes_get_cursor_image_cursor_image_end, 
//GO(xcb_xfixes_get_cursor_image_cursor_image_length, 
//GO(xcb_xfixes_get_cursor_image_reply, 
//GO(xcb_xfixes_get_cursor_image_sizeof, 
//GO(xcb_xfixes_get_cursor_image_unchecked, 
//GO(xcb_xfixes_get_cursor_name, 
//GO(xcb_xfixes_get_cursor_name_name, 
//GO(xcb_xfixes_get_cursor_name_name_end, 
//GO(xcb_xfixes_get_cursor_name_name_length, 
//GO(xcb_xfixes_get_cursor_name_reply, 
//GO(xcb_xfixes_get_cursor_name_sizeof, 
//GO(xcb_xfixes_get_cursor_name_unchecked, 
//GO(xcb_xfixes_hide_cursor, 
//GO(xcb_xfixes_hide_cursor_checked, 
DATA(xcb_xfixes_id, 8)
//GO(xcb_xfixes_intersect_region, 
//GO(xcb_xfixes_intersect_region_checked, 
//GO(xcb_xfixes_invert_region, 
//GO(xcb_xfixes_invert_region_checked, 
GO(xcb_xfixes_query_version, pFpuu)
GO(xcb_xfixes_query_version_reply, pFpup)
GO(xcb_xfixes_query_version_unchecked, pFpuu)
//GO(xcb_xfixes_region_end, 
//GO(xcb_xfixes_region_extents, 
//GO(xcb_xfixes_region_extents_checked, 
//GO(xcb_xfixes_region_next, 
//GO(xcb_xfixes_select_cursor_input, 
//GO(xcb_xfixes_select_cursor_input_checked, 
GO(xcb_xfixes_select_selection_input, pFppppu)
GO(xcb_xfixes_select_selection_input_checked, pFppppu)
GO(xcb_xfixes_set_cursor_name, pFppWp)
GO(xcb_xfixes_set_cursor_name_checked, pFppWp)
GO(xcb_xfixes_set_cursor_name_name, pFp)
GO(xcb_xfixes_set_cursor_name_name_end, pFp)
GO(xcb_xfixes_set_cursor_name_name_length, iFp)
GO(xcb_xfixes_set_cursor_name_sizeof, iFp)
//GO(xcb_xfixes_set_gc_clip_region, 
//GO(xcb_xfixes_set_gc_clip_region_checked, 
//GO(xcb_xfixes_set_picture_clip_region, 
//GO(xcb_xfixes_set_picture_clip_region_checked, 
//GO(xcb_xfixes_set_region, 
//GO(xcb_xfixes_set_region_checked, 
//GO(xcb_xfixes_set_region_rectangles, 
//GO(xcb_xfixes_set_region_rectangles_iterator, 
//GO(xcb_xfixes_set_region_rectangles_length, 
//GO(xcb_xfixes_set_region_sizeof, 
GO(xcb_xfixes_set_window_shape_region, pFpuuwwu)
GO(xcb_xfixes_set_window_shape_region_checked, pFpuuwwu)
//GO(xcb_xfixes_show_cursor, 
//GO(xcb_xfixes_show_cursor_checked, 
//GO(xcb_xfixes_subtract_region, 
//GO(xcb_xfixes_subtract_region_checked, 
//GO(xcb_xfixes_translate_region, 
//GO(xcb_xfixes_translate_region_checked, 
//GO(xcb_xfixes_union_region, 
//GO(xcb_xfixes_union_region_checked,
